# Customising Elysia Overview

If you haven't already, you should read the [basic usage guide](../basic.md) and the [advanced usage guide](../advanced_usage.md) (which details exactly how to specify custom agent descriptions and styles).

There are many ways you can make Elysia into a completely custom app with its own goals and tools. This section will detail exactly how you can create tools, how to interact with the Elysia decision tree's objects and to create your own.

- [Technical Overview](technical_overview.md)
- [How to create your own tools](advanced_tool_construction.md)
- [How to interact with the Elysia Environment](environment.md)
- [How to create your own objects](custom_objects.md)
